<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Publication_model extends CI_Model {

	var $table = 'publication';
	var $column = array('name','code_no'); //set column field database for order and search
	var $order = array('id' => 'desc'); // default order 

	public function __construct()
	{
		parent::__construct();
		$this->load->database();
		
	}

	private function _get_datatables_query()
	{
		
		$this->db->from($this->table);
		
		$i = 0;
	
		foreach ($this->column as $item) // loop column 
		{
			if($_POST['search']['value']) // if datatable send POST for search
			{
				
				if($i===0) // first loop
				{
					$this->db->group_start(); // open bracket. query Where with OR clause better with bracket. because maybe can combine with other WHERE with AND. 
					$this->db->like($item, $_POST['search']['value']);
				}
				else
				{
					$this->db->or_like($item, $_POST['search']['value']);
				}

				if(count($this->column) - 1 == $i) //last loop
					$this->db->group_end(); //close bracket
			}
			$column[$i] = $item; // set column array variable to order processing
			$i++;
		}
		
		if(isset($_POST['order'])) // here order processing
		{
			$this->db->order_by($column[$_POST['order']['0']['column']], $_POST['order']['0']['dir']);
		} 
		else if(isset($this->order))
		{
			$order = $this->order;
			$this->db->order_by(key($order), $order[key($order)]);
		}
	}

	function get_datatables()
	{
		$this->_get_datatables_query();
		if($_POST['length'] != -1)
		$this->db->limit($_POST['length'], $_POST['start']);
		
		$query = $this->db->get();
		return $query->result();
	}
	
	public function get_all()
	{
		$this->db->from($this->table);
		$this->db->where('status="1"');
		$query = $this->db->get();

		return $query->result();
	}
	
	

	function count_filtered()
	{
		$this->_get_datatables_query();
		$query = $this->db->get();
		return $query->num_rows();
	}

	public function count_all()
	{
		$this->db->from($this->table);
		
		return $this->db->count_all_results();
	}

	public function get_by_id($id)
	{
		$this->db->from($this->table);
		$this->db->where('id',$id);
		$query = $this->db->get();

		return $query->row();
	}

public function totalPublication()
	{
		$pub_query = $this->db->query('select count(id) as totalPub from publication where status="1"');
		
		$query = $pub_query->row();
		return $query->totalPub;
	}

	public function save($data)
	{
		$this->db->insert($this->table, $data);
		return $this->db->insert_id();
	}

	public function update($where, $data)
	{
		$this->db->update($this->table, $data, $where);
		return $this->db->affected_rows();
	}
	
	public function delete_by_id($id)
	{
		$this->db->where('id', $id);
		$this->db->delete($this->table);
	}
	
	
	
	

//////////////// reporting part for Individual Publication //////////////////////

public function subscriber_by_daterange($pub,$start,$end,$type){
if($type !='') {$qr = "select * from subscriber  where start_date between '".$start."' and '".$end."' and publication_id='".$pub."' and type='".$type."'";}
if($type =='') {$qr = "select * from subscriber  where start_date between '".$start."' and '".$end."' and publication_id='".$pub."'";}
        $query = $this->db->query($qr);
			
$myquery = $query->result();

return $myquery;

    }

public function total_subscribers($pub,$start,$end,$type){
if($type !='') {$qr ="select count(id) as total_subscriber from  subscriber   where start_date between '".$start."' and '".$end."' and publication_id='".$pub."' and type='".$type."'";}
if($type =='') {$qr ="select count(id) as total_subscriber from  subscriber   where start_date between '".$start."' and '".$end."' and publication_id='".$pub."'";}
        $query = $this->db->query($qr);
			
$myquery = $query->row();

return $myquery;

    }  

public function total_income($pub,$start,$end,$type){
if($type !='') {$qr ="select sum(fee) as income from  subscriber   where start_date between '".$start."' and '".$end."' and publication_id='".$pub."' and type='".$type."'";}
if($type =='') {$qr ="select sum(fee) as income from  subscriber   where start_date between '".$start."' and '".$end."' and publication_id='".$pub."'";}
$query = $this->db->query($qr);

$myquery = $query->row();

return $myquery;

    } 

public function total_adIncome($pub,$start,$end,$type){
if($type !='') {$qr ="SELECT sum( payment.amount ) AS adIncome, payment.payment_for, payment.payment_key, subscriber.type, advertisement_contract.id,advertisement_contract.publication_id FROM payment, subscriber, advertisement_contract WHERE advertisement_contract.id = payment.payment_key AND payment.payment_for = 'contract' AND payment.payment_date BETWEEN '".$start."' and '".$end."' AND advertisement_contract.publication_id = '".$pub."' AND TYPE = '".$type."'";}
if($type =='') {$qr ="select sum(amount) adIncome from payment inner join advertisement_contract on advertisement_contract.id = payment.payment_key
 where payment.payment_for = 'contract' and payment.payment_date between '".$start."' and '".$end."' and advertisement_contract.publication_id='".$pub."'";}
$query = $this->db->query($qr);

$myquery = $query->row();

return $myquery;

    }    
    
public function total_subscriber_by_category($pub,$start,$end,$cat,$type){
if($type !='') {$qr ="select count(id) as total_cat_subscriber from  subscriber   where start_date between '".$start."' and '".$end."' and publication_id='".$pub."' and category='".$cat."' and type='".$type."'";}
if($type =='') {$qr ="select count(id) as total_cat_subscriber from  subscriber   where start_date between '".$start."' and '".$end."' and publication_id='".$pub."' and category='".$cat."'";}
$query = $this->db->query($qr);

$myquery = $query->row();

return $myquery;

    }   
  


public function subscriber_by_type($pub,$start,$end,$type){
        $query = $this->db->query("select * from subscriber_meta inner join subscriber on subscriber.id = subscriber_meta.subscriber_id where subscriber_meta.meta_key !='billing_address' and subscriber_meta.start_date between '".$start."' and '".$end."' and subscriber.publication_id='".$pub."' and subscriber.type='".$type."'");
			
$myquery = $query->result();

return $myquery;

    }
///////// end of Individual Publication reporting part /////////////		
	
	

}
