<?php 
defined('BASEPATH') OR exit('No direct script access allowed');

class Subscriber_model extends CI_Model {

	var $table = 'subscriber';
	var $column = array('name','email','phone','address'); //set column field database for order and search
	var $order = array('id' => 'desc'); // default order 

	public function __construct()
	{
		parent::__construct();
		$this->load->database();
		
	}

	private function _get_datatables_query()
	{
		
		$this->db->from($this->table);
		//$this->db->where('contact_type','1');

		$i = 0;
	
		foreach ($this->column as $item) // loop column 
		{
			if($_POST['search']['value']) // if datatable send POST for search
			{
				
				if($i===0) // first loop
				{
					$this->db->group_start(); // open bracket. query Where with OR clause better with bracket. because maybe can combine with other WHERE with AND. 
					$this->db->like($item, $_POST['search']['value']);
				}
				else
				{
					$this->db->or_like($item, $_POST['search']['value']);
				}

				if(count($this->column) - 1 == $i) //last loop
					$this->db->group_end(); //close bracket
			}
			$column[$i] = $item; // set column array variable to order processing
			$i++;
		}
		
		if(isset($_POST['order'])) // here order processing
		{
			$this->db->order_by($column[$_POST['order']['0']['column']], $_POST['order']['0']['dir']);
		} 
		else if(isset($this->order))
		{
			$order = $this->order;
			$this->db->order_by(key($order), $order[key($order)]);
		}
	}

	function get_datatables($publication)
	{
		$this->_get_datatables_query($publication);
		if($_POST['length'] != -1)
		$this->db->limit($_POST['length'], $_POST['start']);
		$this->db->where('publication_id',$publication);
		$query = $this->db->get();
		return $query->result();
	}
	
	public function get_all($pub)
	{
		$this->db->from($this->table);
		$this->db->where('publication_id',$pub);
		$query = $this->db->get();

		return $query->result_array();
	}
	
	 public function fetch_clients($limit, $start) {
        $this->db->limit($limit, $start);
        $this->db->from($this->table);
		$this->db->where('contact_type','1');
		$query = $this->db->get();

		return $query->result();
   }


	function count_filtered()
	{
		$this->_get_datatables_query();
		$query = $this->db->get();
		return $query->num_rows();
	}

	public function count_all()
	{
		$this->db->from($this->table);
		$this->db->where('status','active');
		return $this->db->count_all_results();
	}

	public function get_by_id($id)
	{
		$this->db->from($this->table);
		$this->db->where('id',$id);
		$query = $this->db->get();

		return $query->row();
	}

public function subscriber_percentage($cat,$status)
	{
		$pub_query = $this->db->query('select count(id) as totalSubscriber from subscriber where category="'.$cat.'" and status="'.$status.'"');
		
		$query = $pub_query->row();
		return $query->totalSubscriber;
	}

public function totalDashboardSubscriber()
	{
		$pub_query = $this->db->query("SELECT subscriber.id as subID, subscriber.name as Name, subscriber.category as Category, subscriber.company as Company, subscriber.email as Email, subscriber.phone as Phone, subscriber.start_date, subscription_type.title as Type, subscription_type.duration, (DATE_ADD( subscriber.start_date, INTERVAL subscription_type.duration DAY )) AS end_date, CURDATE( ) FROM subscriber, subscription_type WHERE subscriber.type = subscription_type.id AND CURDATE( ) < ( DATE_ADD( subscriber.start_date, INTERVAL subscription_type.duration DAY ) )");
		
		$query = $pub_query->num_rows();
		return $query;
	}


public function totalSubscriber($pub)
	{
		$pub_query = $this->db->query('select count(id) as totalSubscriber from subscriber where status="active" and publication_id="'.$pub.'"');
		
		$query = $pub_query->row();
		return $query->totalSubscriber;
	}

public function totalExpiredSubscriber($pub)
	{
		$pub_query = $this->db->query("SELECT subscriber.id as subID, subscriber.name as Name, subscriber.category as Category, subscriber.company as Company, subscriber.email as Email, subscriber.phone as Phone, subscriber.start_date, subscription_type.title as Type, subscription_type.duration, (DATE_ADD( subscriber.start_date, INTERVAL subscription_type.duration DAY )) AS end_date, CURDATE( ) FROM subscriber, subscription_type WHERE subscriber.type = subscription_type.id AND CURDATE( ) > ( DATE_ADD( subscriber.start_date, INTERVAL subscription_type.duration DAY ) ) and subscriber.publication_id='".$pub."'");
		
		$query = $pub_query->num_rows();
		return $query;
	}

public function weeklySubscriber()
	{
	$start = date('Y-m-d',strtotime('-7 days'));
	$end = date('Y-m-d');
		$pub_query = $this->db->query('select count(id) as weekly_subscriber from subscriber where status="active" and start_date between"'.$start.'" and "'.$end.'"');
		
		$query = $pub_query->row();
		return $query->weekly_subscriber;
	}


public function subscription_revenue()
	{
$pub_query = $this->db->query("SELECT SUM( fee ) AS SubscriptionRevenue FROM subscription_type INNER JOIN subscriber ON subscription_type.id = subscriber.type WHERE subscriber.category = 'Paid'");
		
		$query = $pub_query->row();
		return $query->SubscriptionRevenue;
	}

public function weeklyRevenue()
	{
	$start = date('Y-m-d',strtotime('-7 days'));
	$end = date('Y-m-d');
$pub_query = $this->db->query("SELECT SUM( fee ) AS weekly_revenue FROM subscription_type INNER JOIN subscriber ON subscription_type.id = subscriber.type WHERE subscriber.category = 'Paid' and subscriber.start_date between '".$start."' and '".$end."'");
		
		$query = $pub_query->row();
		return $query->weekly_revenue;
	}



	
	public function get_by_method($id)
	{
		$this->db->from($this->table);
		$this->db->where('distribution_method',$id);
		$query = $this->db->get();

		return $query->result();
	}
	
	public function get_by_pubid($id)
	{
		$this->db->select('COUNT(id) as total_subscriber from subscriber where publication_id='.$id);
  //$this->db->get('tablename', 10);
		$query = $this->db->get();

		return $query->row();
	}
	
	public function get_by_category($pub,$cat)
	{
	 
		 $query = $this->db->query("SELECT subscriber.id as id, subscriber.name as Name, subscriber.category as Category, subscriber.company as Company, subscriber.email as Email, subscriber.phone as Phone, subscriber.start_date, subscription_type.title as Type, subscription_type.duration, (DATE_ADD( subscriber.start_date, INTERVAL subscription_type.duration DAY )) AS end_date, CURDATE( ) FROM subscriber, subscription_type WHERE subscriber.type = subscription_type.id AND CURDATE( ) < ( DATE_ADD( subscriber.start_date, INTERVAL subscription_type.duration DAY ) ) and subscriber.publication_id='".$pub."' and subscriber.category ='".$cat."' and subscriber.status ='active' " );
			
$myquery = $query->result();

return $myquery;
		
	}
public function get_by_type($pub,$type)
	{
		 $query = $this->db->query("SELECT subscriber.id as id, subscriber.name as Name, subscriber.category as Category, subscriber.company as Company, subscriber.email as Email, subscriber.phone as Phone, subscriber.start_date, subscription_type.title as Type, subscription_type.duration, (DATE_ADD( subscriber.start_date, INTERVAL subscription_type.duration DAY )) AS end_date, CURDATE( ) FROM subscriber, subscription_type WHERE subscriber.type = subscription_type.id AND CURDATE( ) < ( DATE_ADD( subscriber.start_date, INTERVAL subscription_type.duration DAY ) ) and subscriber.publication_id='".$pub."' and subscriber.type ='".$type." ' and subscriber.type !='0' and subscriber.status ='active' " );
			
$myquery = $query->result();

return $myquery;
	}
public function get_by_group($pub,$grp)
	{
		 $query = $this->db->query("SELECT subscriber.id as id, subscriber.name as Name, subscriber.category as Category, subscriber.company as Company, subscriber.email as Email, subscriber.phone as Phone, subscriber.start_date, subscription_type.title as Type, subscription_type.duration, (DATE_ADD( subscriber.start_date, INTERVAL subscription_type.duration DAY )) AS end_date, CURDATE( ) FROM subscriber, subscription_type WHERE subscriber.type = subscription_type.id AND CURDATE( ) < ( DATE_ADD( subscriber.start_date, INTERVAL subscription_type.duration DAY ) ) and subscriber.publication_id='".$pub."' and subscriber.group ='".$grp." ' and subscriber.group !='0'  and subscriber.status ='active' " );
			
$myquery = $query->result();

return $myquery;
		 
	}

public function active_comparison($year)
 {
 $start = date("Y-".$month."-01", strtotime($year.'-'.$month.'-01'));// get start date from here
 $end = date("Y-".$month."-t", strtotime($start));
 
 $sub_query = $this->db->query("select count(id) as totalSub from subscriber where start_date between '".$start."' and '".$end."' and status='active'");
 $sub = $sub_query->row();
 
 return $sub->totalSub;
 }
 
 public function top_subscriber($year)
  {
   $start = date("Y-01-01", strtotime($year.'-01-01'));// get start date from here
     $end = date("Y-12-t", strtotime($year));
     
$adv_query = $this->db->query( "SELECT id, name, email FROM subscriber WHERE start_date BETWEEN  '".$start."' AND '".$end."' and status='active' order by start_date desc limit 5"); 

$adv =  $adv_query->result();
  return $adv;
  }

public function subscriber_statistics($start,$end)
  {
  
  $year = date("Y",strtotime($start));
   $month = date("M",strtotime($start));
   $day = date("D",strtotime($start));
   
   $diff=date_diff($start,$end);
  
 
$sub_query = $this->db->query( "SELECT subscription_type.fee, subscriber.start_date FROM subscription_type, subscriber WHERE subscriber.type = subscription_type.id AND subscriber.start_date BETWEEN  '".$start."' AND  '".$end."' order by start_date asc "); 

$sub =  $sub_query->result();
  return $sub;
  }








	public function save($data)
	{
		$this->db->insert($this->table, $data);
		return $this->db->insert_id();
	}

	public function update($where, $data)
	{
		$this->db->update($this->table, $data, $where);
		return $this->db->affected_rows();
	}
	
	public function delete_by_id($id)
	{
		$this->db->where('id', $id);
		$this->db->delete($this->table);
	}
	
	function getSearch($search){
		$this->db->select("*");
		
		$where = "name like '%".$search."%' AND contact_type='1'";

         $this->db->where($where);
		$this->db->from('contact');
		$query = $this->db->get();
		return $query->result();
	}

public function transactionByDate($from, $to){

        $this->db->from($this->table);
$this->db->where('trans_date between "'.$from.'" and "'.$to.'"'); // deposit = ac_from(0)
		$query = $this->db->get();
		return $query->result();

    }
/*
public function expired_in_duration($pub,$duration)
  {
  $query = $this->db->query("SELECT subscriber.id AS subscriberID, subscription_type.duration AS Duration, subscriber_meta.start_date AS startDate FROM subscriber, subscription_type, subscriber_meta WHERE subscriber.id = subscriber_meta.subscriber_id AND subscriber_meta.meta_key != 'subscription' AND subscriber_meta.meta_key != 'billing_address' AND subscriber.publication_id='".$pub."' GROUP BY subscriber.id");
			
$myquery = $query->result();

foreach($myquery as $myinfo) {
			 
			 
 $start_date = $myinfo->startDate;
$next_renewal_date= date('Y-m-d', strtotime($start_date. ' +'.$duration.' days'));

$today = date('Y-m-d');

$diff = abs(strtotime($today) - strtotime($next_renewal_date));

$total_day = floor($diff/(60*60*24));

if($total_day<=30) { // if the difference is less than/equal to 30 days then show the subscriber in the list
			 
			$subquery = $this->db->get_where('subscriber', array('id' => $myinfo->subscriberID));
			          $subs = $subquery->row(); 

                                  }
          }
  
  }

*/

public function custom_search_result($pubID){
       $query = $this->db->query("SELECT subscriber.id as subID, subscriber.name as Name, subscriber.category as Category, subscriber.company as Company, subscriber.email as Email, subscriber.phone as Phone, subscriber.start_date, subscription_type.title as Type, subscription_type.duration, (DATE_ADD( subscriber.start_date, INTERVAL subscription_type.duration DAY )) AS end_date, CURDATE( ) FROM subscriber, subscription_type WHERE subscriber.type = subscription_type.id AND CURDATE( ) < ( DATE_ADD( subscriber.start_date, INTERVAL subscription_type.duration DAY ) ) and subscriber.publication_id='".$pubID."' and subscriber.status !='closed'");
			
$myquery = $query->result();

return $myquery;

    }
 
public function active_subscriber_result($mystring){
        $this->db->from($this->table);
$this->db->where('publication_id = "'.$mystring.'" and status="active"'); // 	

		$query = $this->db->get();
		return $query->result();

    }

public function closed_subscriber_result($mystring){
        $this->db->from($this->table);
$this->db->where('publication_id = "'.$mystring.'" and status="closed"'); // 	

		$query = $this->db->get();
		return $query->result();

    }

public function pending_subscriber_result($mystring){
        $this->db->from($this->table);
$this->db->where('publication_id = "'.$mystring.'" and status="pending"'); // 	

		$query = $this->db->get();
		return $query->result();

    }

public function paid_subscriber_result($mystring){
        $this->db->from($this->table);
$this->db->where('publication_id = "'.$mystring.'" and status="active" and category="Paid"'); // 

		$query = $this->db->get();
		return $query->result();

    }

public function complimentary_subscriber_result($mystring){
        $this->db->from($this->table);
$this->db->where('publication_id = "'.$mystring.'" and status="active" and category="Complementary"'); // 

		$query = $this->db->get();
		return $query->result();

    }
	
public function total_paid_subscriber($id){
      $this->db->select('COUNT(id) as total_paid from subscriber where publication_id="'.$id.'" and status="active" and category="Paid"');
  //$this->db->get('tablename', 10);
		$query = $this->db->get();

		return $query->row();

    }
 
 public function total_complementary_subscriber($id){
      $this->db->select('COUNT(id) as total_complementary from subscriber where publication_id="'.$id.'" and status="active" and category="Complementary"');
  //$this->db->get('tablename', 10);
		$query = $this->db->get();

		return $query->row();

    }
  public function total_active_subscriber($id){
      $this->db->select('COUNT(id) as total_active from subscriber where publication_id="'.$id.'" and status="active"');
  //$this->db->get('tablename', 10);
		$query = $this->db->get();

		return $query->row();

    }

//////////////// reporting part //////////////////////

public function subscriber_by_daterange($pub,$start,$end,$type){
if($type !='') {$qr = "select * from subscriber  where start_date between '".$start."' and '".$end."' and publication_id='".$pub."' and type='".$type."'";}
if($type =='') {$qr = "select * from subscriber  where start_date between '".$start."' and '".$end."' and publication_id='".$pub."'";}
        $query = $this->db->query($qr);
			
$myquery = $query->result();

return $myquery;

    }

public function total_subscribers($pub,$start,$end,$type){
if($type !='') {$qr ="select count(id) as total_subscriber from  subscriber   where start_date between '".$start."' and '".$end."' and publication_id='".$pub."' and type='".$type."'";}
if($type =='') {$qr ="select count(id) as total_subscriber from  subscriber   where start_date between '".$start."' and '".$end."' and publication_id='".$pub."'";}
        $query = $this->db->query($qr);
			
$myquery = $query->row();

return $myquery;

    }  

public function total_income($pub,$start,$end,$type){
 // select sum(subscription_type.fee) as subIncome from subscription_type inner join subscriber on subscriber.type = subscription_type.id where subscriber.start_date between '2016-08-01' and '2016-09-23' and subscriber.publication_id='1' 
if($type !='') {$qr ="select sum(subscription_type.fee) as subIncome from subscription_type inner join subscriber on subscriber.type = subscription_type.id where subscriber.start_date between '".$start."' and '".$end."' and subscriber.publication_id='".$pub."' and subscriber.type='".$type."'";}
if($type =='') {$qr ="select sum(subscription_type.fee) as subIncome from subscription_type inner join subscriber on subscriber.type = subscription_type.id where subscriber.start_date between '".$start."' and '".$end."' and subscriber.publication_id='".$pub."'";}
$query = $this->db->query($qr);

$myquery = $query->row();

return $myquery;

    } 

public function total_adIncome($pub,$start,$end,$type){
if($type !='') {$qr ="SELECT sum( payment.amount ) AS adIncome, payment.payment_for, payment.payment_key, subscriber.type, advertisement_contract.id,advertisement_contract.publication_id FROM payment, subscriber, advertisement_contract WHERE advertisement_contract.id = payment.payment_key AND payment.payment_for = 'contract' AND payment.payment_date BETWEEN '".$start."' and '".$end."' AND advertisement_contract.publication_id = '".$pub."' AND TYPE = '".$type."'";}
if($type =='') {$qr ="select sum(amount) adIncome from payment inner join advertisement_contract on advertisement_contract.id = payment.payment_key
 where payment.payment_for = 'contract' and payment.payment_date between '".$start."' and '".$end."' and advertisement_contract.publication_id='".$pub."'";}
$query = $this->db->query($qr);

$myquery = $query->row();

return $myquery;

    }    
    
public function total_subscriber_by_category($pub,$start,$end,$cat,$type){
if($type !='') {$qr ="select count(id) as catSubscriber from  subscriber   where start_date between '".$start."' and '".$end."' and publication_id='".$pub."' and category='".$cat."' and type='".$type."'";}
if($type =='') {$qr ="select count(id) as catSubscriber from  subscriber   where start_date between '".$start."' and '".$end."' and publication_id='".$pub."' and category='".$cat."'";}
$query = $this->db->query($qr);

$myquery = $query->row();

return $myquery;

    }   
  


public function subscriber_by_type($pub,$start,$end,$type){
        $query = $this->db->query("select * from subscriber_meta inner join subscriber on subscriber.id = subscriber_meta.subscriber_id where subscriber_meta.meta_key !='billing_address' and subscriber_meta.start_date between '".$start."' and '".$end."' and subscriber.publication_id='".$pub."' and subscriber.type='".$type."'");
			
$myquery = $query->result();

return $myquery;

    }


///////// end of reporting part /////////////	

}
